# Get Started

This Get Started guide is intended as a quick way to start programming with **vgrid**. You can try out vgrid by using Goolge Colab ([![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/opengeoshub/vgrid/blob/master)) or Binder ([![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/opengeoshub/vgrid/HEAD)) without having to install anything on your computer.

## vgrid Modules

The key functionality of the vgrid Python package is organized into nine modules as shown in the table below.

| Module     | Description                                                                                |
| ---------- | ------------------------------------------------------------------------------------------ |
| conversion | Convert latlon to DGGS, geojson to DGGS, raster to DGGS, CSV to DGGS, compact, expand DGGS |
| generator  | Generate DGGS at a specfic bounding box and resolution                                     |
| resampling | Resampling different DGGS                                                                  |
| binning    | Point binning to DGGS                                                                      |

## Launch Jupyter notebook

```bash
conda activate env_name
jupyter notebook
```

